@@ -88,9 +88,7 @@ class ParseableFormatter(BaseFormatter[Any]):
         result = (
             f"[filename]{self._format_path(match.filename or '')}[/][dim]:{match.position}:[/] "
             f"[{match.level}][bold]{self.escape(match.tag)}[/bold]"
-            f": {match.message}"
-            if not options.quiet
-            else "[/]"
+            f"{ f': {match.message}' if not options.quiet else '' }[/]"
         )
         if match.level != "error":
             result += f" [dim][{match.level}]({match.level})[/][/]"
@@ -150,6 +148,9 @@ class CodeclimateJSONFormatter(BaseFormatter[Any]):
             issue["type"] = "issue"
             issue["check_name"] = match.tag or match.rule.id  # rule-id[subrule-id]
             issue["categories"] = match.rule.tags
+            if match.rule.url:
+                # https://github.com/codeclimate/platform/issues/68
+                issue["url"] = match.rule.url
             issue["severity"] = self._severity_to_level(match)
             issue["description"] = self.escape(str(match.message))
             issue["fingerprint"] = hashlib.sha256(
