@@ -212,7 +212,7 @@ def test_extract_from_list_recursive() -> None:
     assert list(block["block"]) == test_list
 
     test_list_recursive = utils.extract_from_list(blocks, ["block"], recursive=True)
-    assert block["block"] + block["block"][0]["block"] == test_list_recursive  # type: ignore
+    assert block["block"] + block["block"][0]["block"] == test_list_recursive
 
 
 @pytest.mark.parametrize(
@@ -221,7 +221,7 @@ def test_extract_from_list_recursive() -> None:
         pytest.param("{{ playbook_dir }}", "/a/b/c", id="simple"),
         pytest.param(
             "{{ 'hello' | doesnotexist }}",
-            "{{ 'hello' | doesnotexist }}",
+            "hello",  # newer implementation ignores unknown filters
             id="unknown_filter",
         ),
         pytest.param(
@@ -238,7 +238,12 @@ def test_extract_from_list_recursive() -> None:
 )
 def test_template(template: str, output: str) -> None:
     """Verify that resolvable template vars and filters get rendered."""
-    result = utils.template("/base/dir", template, dict(playbook_dir="/a/b/c"))
+    result = utils.template(
+        basedir="/base/dir",
+        value=template,
+        variables=dict(playbook_dir="/a/b/c"),
+        fail_on_error=False,
+    )
     assert result == output
 
 
@@ -314,8 +319,8 @@ def test_cli_auto_detect(capfd: CaptureFixture[str]) -> None:
     assert "Excluded removed files using: git ls-files --deleted -z" in err
     # An expected rule match from our examples
     assert (
-        "examples/playbooks/empty_playbook.yml:1: "
-        "syntax-check: Empty playbook, nothing to do" in out
+        "examples/playbooks/empty_playbook.yml:1:1: "
+        "warning[empty-playbook]: Empty playbook, nothing to do" in out
     )
     # assures that our ansible-lint config exclude was effective in excluding github files
     assert "Identified: .github/" not in out
